Gérer efficacement vos dossiers d'assistance IBM Cloud

Apprenez à gérer vos dossiers d'assistance IBM Cloud, y compris le suivi de l'avancement, la mise à jour des dossiers et la gestion des listes de surveillance pour une résolution efficace des problèmes.

Pour afficher et gérer vos cas de support, accédez à la page Gérer les cas. Si vous êtes un utilisateur d'infrastructure classique et que vous ne voyez pas de liste d'un cas précédent, cliquez sur Afficher les cas de l'infrastructure classique. Vous pouvez également obtenir une vue rapide de vos cinq derniers dossiers en cours en tapant case status dans l'assistant AI de IBM Cloud.

Vous pouvez également consulter vos dossiers d'assistance IBM sur la page Gérer les dossiers, mais ils ne peuvent être gérés que dans le portail d'assistance IBM. L'accès à la visualisation de ces cas est contrôlé dans le portail d'assistance IBM. Pour plus d'informations sur l'accès, voir Gestion de l'accès à votre compte d'assistance.

Affichage des cas de support à l'aide de l'API

Vous pouvez ouvrir un cas de support à l'aide d'un programme en appelant l'API, comme illustré dans l'exemple de demande ci-après. Pour plus d'informations, consultez l'API de gestion des dossiers.

Pour afficher un cas, voir les exemples suivants :

curl -X GET 'https://support-center.cloud.ibm.com/case-management/v1/cases/{case_number}?fields=number,updated_at,resources' -H 'Authorization: TOKEN' \
GetCaseOptions getCaseOptions = new GetCaseOptions.Builder()
  .caseNumber(caseNumber)
  .addFields(GetCaseOptions.Fields.DESCRIPTION)
  .addFields(GetCaseOptions.Fields.STATUS)
  .addFields(GetCaseOptions.Fields.SEVERITY)
  .addFields(GetCaseOptions.Fields.CREATED_BY)
  .build();
Response<Case> response = service.getCase(getCaseOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const fieldsToReturn = [
  CaseManagementV1.GetCaseConstants.Fields.DESCRIPTION,
  CaseManagementV1.GetCaseConstants.Fields.STATUS,
  CaseManagementV1.GetCaseConstants.Fields.SEVERITY,
  CaseManagementV1.GetCaseConstants.Fields.CREATED_BY,
];
const params = {
  caseNumber: caseNumber,
  fields: fieldsToReturn,
};
caseManagementService.getCase(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
fields_to_return = [
  GetCaseEnums.Fields.DESCRIPTION,
  GetCaseEnums.Fields.STATUS,
  GetCaseEnums.Fields.SEVERITY,
  GetCaseEnums.Fields.CREATED_BY,
]
case = case_management_service.get_case(
  case_number=case_number,
  fields=fields_to_return
).get_result()
print(json.dumps(case, indent=2))
getCaseOptions := caseManagementService.NewGetCaseOptions(
  caseNumber,
)
getCaseOptions.SetFields([]string{
  casemanagementv1.GetCaseOptionsFieldsDescriptionConst,
  casemanagementv1.GetCaseOptionsFieldsStatusConst,
  casemanagementv1.GetCaseOptionsFieldsSeverityConst,
  casemanagementv1.GetCaseOptionsFieldsCreatedByConst,
})
caseVar, response, err := caseManagementService.GetCase(getCaseOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Mise à jour de cas de support à l'aide de l'API

L'exemple de demande suivant montre comment mettre à jour un cas de support à l'aide d'un programme. Pour plus d'informations, consultez l'API de gestion des dossiers.

curl -X PUT '/case-management/v1/cases/{case_number}/status' -H 'Authorization: TOKEN' -d '{
  "action": "resolve",
  "comment": "The issue is resolved. Thank you!",
  "resolution_code": 1
}'
ResolvePayload statusPayloadModel = new ResolvePayload.Builder()
  .action("resolve")
  .comment("The problem has been resolved.")
  .resolutionCode(1)
  .build();
UpdateCaseStatusOptions updateCaseStatusOptions = new UpdateCaseStatusOptions.Builder()
  .caseNumber(caseNumber)
  .statusPayload(statusPayloadModel)
  .build();
Response<Case> response = service.updateCaseStatus(updateCaseStatusOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const statusPayloadModel = {
  action: 'resolve',
  comment: 'The problem has been resolved.',
  resolution_code: 1,
};
const params = {
  caseNumber: caseNumber,
  statusPayload: statusPayloadModel,
};
caseManagementService.updateCaseStatus(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
status_payload_model = {
  'action': 'resolve',
  'comment': 'The problem has been resolved.',
  'resolution_code': 1,
}
case = case_management_service.update_case_status(
  case_number=case_number,
  status_payload=status_payload_model
).get_result()
print(json.dumps(case, indent=2))
statusPayloadModel := &casemanagementv1.ResolvePayload{
  Action:         core.StringPtr("resolve"),
  Comment:        core.StringPtr("The problem has been resolved."),
  ResolutionCode: core.Int64Ptr(int64(1)),
}
updateCaseStatusOptions := caseManagementService.NewUpdateCaseStatusOptions(
  caseNumber,
  statusPayloadModel,
)
caseVar, response, err := caseManagementService.UpdateCaseStatus(updateCaseStatusOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Ajout de commentaires à des cas de support à l'aide de l'API

L'exemple de demande suivant montre comment ajouter un commentaire à un cas de support à l'aide d'un programme. Pour plus d'informations, consultez l'API de gestion des dossiers.

curl -X PUT '/case-management/v1/cases/{case_number}/comments' -H 'Authorization: TOKEN' -d '{
  "comment": "Test comment api"
}'
AddCommentOptions addCommentOptions = new AddCommentOptions.Builder()
  .caseNumber(caseNumber)
  .comment("This is an example comment.")
  .build();
Response<Comment> response = service.addComment(addCommentOptions).execute();
Comment comment = response.getResult();
System.out.println(comment);
const params = {
  caseNumber: caseNumber,
  comment: 'This is an example comment,',
};
caseManagementService.addComment(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
comment = case_management_service.add_comment(
  case_number=case_number,
  comment='This is an example comment.'
).get_result()
print(json.dumps(comment, indent=2))
addCommentOptions := caseManagementService.NewAddCommentOptions(
  caseNumber,
  "This is an example comment.",
)
comment, response, err := caseManagementService.AddComment(addCommentOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(comment, "", "  ")
fmt.Println(string(b))

Mise à jour des dossiers d'assistance

Sélectionnez le numéro de dossier pour mettre à jour le dossier d'assistance. Vous pouvez ajouter un commentaire, joindre ou supprimer des fichiers, ajouter des ressources ou mettre à jour la liste de surveillance. Pour mettre à jour votre dossier d'assistance, procédez comme suit :

  1. Dans la barre de menu de la console IBM Cloud, cliquez sur l'icône Aide Icône d'aide > Centre d'assistance.
  2. Sélectionnez le dossier d'assistance dans la vignette Dossiers d'assistance récents.
  3. Ajoutez un commentaire, puis cliquez sur Soumettre.
  4. Vous pouvez, si vous le souhaitez, mettre à jour les champs suivants :
    • Ajouter un utilisateur à la liste de suivi
    • Joindre ou supprimer des fichiers
    • Ajouter une ressource spécifique pour un cas d'assistance technique

Ajouter un CRN à un commentaire de cas

L'ajout de détails sur les ressources spécifiques liées à un cas d'assistance permet un triage, une investigation et une résolution plus efficaces. Pour afficher et copier un nom de ressource en nuage (CRN) à ajouter à un cas d'assistance, procédez comme suit :

  1. Dans la console d' IBM Cloud®, cliquez sur l'icône du menu de navigation Menu de > Liste des ressources pour afficher la liste de vos ressources.
  2. Développez les sections pour localiser l'instance de service pour laquelle vous souhaitez récupérer le CRN.
  3. Cliquez sur la ligne de la table. Cette action ouvre le panneau latéral du tableau des ressources, où vous pouvez voir le CRN.
  4. Sélectionnez Copier dans le presse-papiers à côté de la valeur CRN.
  5. Collez la valeur dans un commentaire du dossier d'assistance.

Mise à jour de la liste de surveillance de votre cas de support

Vous pouvez mettre à jour les utilisateurs dans votre compte qui peuvent recevoir des notifications sur votre cas de support en les ajoutant à la liste de surveillance. Les utilisateurs peuvent être ajoutés à la liste de suivi lors de la création d'un dossier d'assistance ou après la création de celui-ci.

Par défaut, les utilisateurs de compte n'ont pas accès à la création, la mise à jour, la recherche ou la consultation de cas. Le titulaire du compte doit accorder l'accès aux utilisateurs en leur attribuant une politique d'accès IAM ( Identity and Access Management ). Pour plus d'informations, voir Attribution d'accès utilisateur pour l'utilisation de cas de support.

Pour vous assurer que les utilisateurs reçoivent des notifications relatives à un cas de support existant que vous avez créé, procédez comme suit pour les ajouter à la liste de surveillance.

  1. Dans la barre de menu de la console IBM Cloud, cliquez sur l'icône Aide Icône d'aide > Centre d'assistance.

  2. Sélectionnez le dossier d'assistance dans la vignette Dossiers d'assistance récents.

  3. Dans la section Liste de suivi, cliquez sur l'icône Paramètres Icône.

  4. Sélectionnez les utilisateurs du compte à ajouter à la liste de surveillance.

    Les utilisateurs qui sont ajoutés à la liste de surveillance doivent être membres du compte sur lequel le cas de support a été créé. Pour plus d'informations sur l'affectation à des utilisateurs de l'accès à votre compte, voir Ajout d'utilisateurs à votre groupe d'accès de gestion des cas.

Types de statut de cas de support

Lorsqu'une réponse de votre part concernant une mise à jour de votre cas de support est requise, le statut Waiting on client s'affiche. Si vous ne fournissez pas de réponse dans un délai de sept jours, le statut est mis à jour sur Resolved. Le cas est ensuite fermé en l'absence de réponse au bout de sept jours supplémentaires. Pour une description de chaque statut, voir le tableau suivant :

Types de statut de cas de support
Statut Description
Nouveau Cas créé qui n'a pas encore été examiné par un ingénieur support.
En cours Cas en cours d'examen.
En attente chez le client L'ingénieur du support a envoyé une demande concernant ce dossier, qui nécessite une réponse de la part de l'utilisateur.
Résolution fournie L'ingénieur support a fourni une solution que l'utilisateur doit appliquer.
Résolu Le cas de support est considéré comme résolu et prêt à être fermé.
Clôturé Le cas est fermé par un ingénieur support et ne peut pas être rouvert.

Escalade de cas de support

Avec un contrat d'assistance payant, vous pouvez utiliser la procédure d'escalade pour signaler des problèmes critiques et faire part de vos préoccupations concernant un dossier d'assistance. Lorsqu'un cas est remonté, l'équipe de support IBM Cloud examine les informations se trouvant dans le cas de support et vous fournit les mises à jour appropriées. Pour plus d'informations sur la gravité des cas, voir Gravité des cas et temps de réponse initiaux.

Pour faire remonter un cas, procédez comme suit :

  1. Contactez IBM Cloud Support par chat ou par téléphone.
    • Cliquez sur Lancer l'assistant AI dans le centre d'assistance et tapez agent pour vous connecter à un agent d'assistance
    • Connectez-vous par téléphone en utilisant le numéro du Centre d'assistance.
  2. Indiquez le numéro de cas de support dont vous disposez et demandez à faire remonter le cas.
  3. Indiquez le motif de l'escalade et expliquez l'impact métier de votre problème.

Plans d'assistance de base : Si vous disposez d'un plan d'assistance de base, l'accès à l'assistance est limité aux cas non techniques. Si votre demande d'assistance nécessite une réponse plus immédiate, envisagez de passer à un plan d'assistance Premium ou Avancé afin de pouvoir attribuer un niveau de gravité à un cas. Pour passer à un niveau supérieur de votre formule d'assistance, créez une demande dans le Centre d'assistance ou contactez un représentant commercial d' IBM Cloud pour obtenir de l'aide.

Recherche de cas de support

Depuis la page Gérer les demandes, vous pouvez filtrer les demandes par statut et rechercher l'ensemble de vos demandes d'assistance à l'aide des paramètres de requête disponibles dans la barre de recherche. Les filtres par défaut sont définis de manière à n'afficher que les dossiers ouverts. Pour afficher les dossiers résolus ou clôturés, mettez à jour le filtre de statut. Tous les paramètres peuvent être utilisés ensemble et saisis dans n'importe quel ordre. Vous pouvez également filtrer les cas en sélectionnant Tous les cas, Mes cas et Liste de surveillance.

Pour plus de détails sur les paramètres de recherche, voir le tableau suivant :

Paramètres et options de la requête de recherche
Paramètre Option Règle
number target case number Ce paramètre ne peut pas être utilisé avec d'autres paramètres. Lorsque le paramètre number est utilisé, tous les autres paramètres et options sont ignorés. Le paramètre number ne remplit pas automatiquement la recherche. Vous devez utiliser le numéro de dossier entier pour lancer la recherche.
sort number
subject
severity
updatedAt
Une seule des options sort peut être utilisée à la fois. Vous pouvez utiliser le préfixe ~ pour inverser l'ordre de tri.
status new
inProgress
waitingOnClient
resolutionProvided
resolved
closed
N'importe quel nombre d'options peut être utilisé. Les options disponibles peuvent être entrées comme status:new,inProgress ou status:new status:inProgress.
page target page to view Si plusieurs résultats de votre recherche s'étendent sur plusieurs pages, vous pouvez afficher vos résultats à partir de n'importe quelle page de résultat. Par exemple, pour afficher la page 5 sur 10, utilisez page:5.
pageSize 10
25
50
100
Taille de la page à afficher. La taille de la page fait référence au nombre de résultats que vous souhaitez charger.

Si vous entrez un terme sans paramètre, les résultats de la recherche s'affichent pour le numéro de cas de support et l'objet du cas.

Exemples de requête et d'URL

Vous pouvez saisir des requêtes dans la barre de recherche en indiquant un paramètre et une option séparés par deux points (:), ou utiliser des paramètres dans une expression URL pour accéder directement à un cas spécifique ou à un groupe de cas sur la page Gérer les cas.

Pour utiliser des paramètres dans l' URL, ajoutez un point d'interrogation (?) à la fin de l' URL. Ensuite, définissez votre paramètre sur l'option que vous sélectionnez. Vous pouvez également séparer les paramètres supplémentaires à l'aide d'un esperluette (&).

Pour rechercher un cas par mot clé, vous pouvez entrer le mot dans la barre de recherche sans paramètre. Pour rechercher un mot clé avec l'URL, utilisez search comme paramètre et définissez un mot clé égal à votre mot clé, par exemple, search=server.

Recherche par numéro de dossier

Entrez ce qui suit dans les cas de support de recherche par numéro de dossier:

Requête
number:CS1234567
URL
https://cloud.ibm.com/unifiedsupport/cases?number=CS1234567

Recherche avec plusieurs paramètres

Vous pouvez rechercher les nouveaux cas de support ainsi que les cas de support en cours, limiter les résultats à 25 par page et qu'ils soient affichés par niveau de gravité. Vous savez aussi que le cas que vous cherchez ne sera pas dans les deux premières pages, donc vous voulez commencer à la page 5. Entrez la requête de recherche suivante :

Requête
status:new,inProgress page:5 pageSize:25 sort:severity
URL
https://cloud.ibm.com/unifiedsupport/cases?status=new&status=inProgress&pageSize=25&sort=severity

Recherche de cas résolus

Entrez la requête suivante pour afficher tous les cas résolus en fonction de leur date de dernière mise à jour:

Requête
sort:~updatedAT status:resolved
URL
https://cloud.ibm.com/unifiedsupport/cases?sort=~updatedAT&status=resolved

Création et gestion des étiquettes de cas

Vous pouvez créer et gérer des étiquettes personnalisées qui peuvent être attachées aux cas de support. Ces étiquettes permettent de classer les cas par service, par incident ou selon une logique personnalisée, ce qui simplifie la recherche, le filtrage et la gestion d'un grand nombre d'interactions de support.

Pour utiliser les balises, le compte du client doit être doté d'un niveau d'assistance Premium.

Création de balises dans votre compte

Avant de pouvoir baliser les cas, vous devez créer des balises au niveau du compte. Pour cela, procédez comme suit :

  1. Naviguez vers Support > Gérer les cas.
  2. Cliquez sur Modifier les balises pour ajouter autant de balises que nécessaire. Ces étiquettes sont personnalisables et peuvent refléter des services, des incidents, des équipes ou toute autre classification pertinente pour votre organisation.
  3. Cliquez sur Sauvegarder.

Chaque étiquette doit être alphanumérique et ne doit pas comporter plus de 40 caractères. Vous pouvez attacher jusqu'à 20 étiquettes à un seul dossier d'assistance.

Gestion des balises dans votre compte

Après avoir créé les balises, vous pouvez les associer à un cas en cliquant sur Balises du cas, puis supprimer les balises en utilisant la même interface.

Pour trouver des cas avec des étiquettes spécifiques, cliquez sur une ou plusieurs étiquettes. Par exemple, cliquez sur tag100 ou tag100 et tag102 pour afficher tous les cas associés.

Seuls les cas contenant toutes les balises sélectionnées sont affichés, car l'option de recherche utilise une condition ET. Le filtrage OR n'est pas pris en charge.

Recevoir des notifications pour les dossiers ouverts à l'aide d'un profil de confiance

Lorsque vous travaillez avec un profil de confiance et que vous ouvrez un dossier d'assistance, vous avez le choix entre deux options pour recevoir des notifications.

Option 1 : Les notifications peuvent être envoyées à votre adresse électronique.

Option 2 : Les notifications peuvent être envoyées à l'adresse électronique associée au profil de confiance.

Pour utiliser la deuxième option, une adresse électronique doit être associée au profil de confiance qui n'est pas un identifiant de service, une ressource en nuage ou une ressource informatique.